@@ -1,5 +1,5 @@
 package Ryu::Exception;
-$Ryu::Exception::VERSION = '0.005';
+$Ryu::Exception::VERSION = '0.006';
 use strict;
 use warnings;
 
@@ -11,7 +11,7 @@ Ryu::Exception - support for L<Future>-style failure information
 
  use Ryu::Exception;
  my $exception = Ryu::Exception->new(
-  type => 'http',
+  type    => 'http',
   message => '404 response'
   details => [ $response, $request ]
  );
@@ -78,21 +78,26 @@ sub fail {
 	use namespace::clean qw(blessed);
 	my ($self, $f) = @_;
 	die "expects a Future" unless blessed($f) && $f->isa('Future');
-	return $self->future->on_ready($f);
+	$self->as_future->on_ready($f);
+    $f;
 }
 
-=head2 future
+=head2 as_future
 
 Returns a failed L<Future> containing the message, type and details from
 this exception.
 
 =cut
 
-sub future {
+sub as_future {
 	my ($self) = @_;
 	return Future->fail($self->message, $self->type, $self->details);
 }
 
+# Legacy support - will be dropped in 1.0,
+# probably should warn before then anyway.
+*future = *as_future;
+
 =head2 from_future
 
 Extracts failure information from a L<Future> and instantiates accordingly.
@@ -108,7 +113,7 @@ sub from_future {
 	my ($msg, $type, @details) = $f->failure or die "Future is not failed?";
 	$class->new(
 		message => $msg,
-		type => $type,
+		type    => $type,
 		details => \@details
 	)
 }
